@@ -1,7 +1,7 @@
 
 import copy
 import json
-
+from openapi_schema_to_json_schema import to_json_schema
 import jsonschema
 
 try:
@@ -42,7 +42,7 @@ class ValidatedJSONField(JSONField):
     A models.JSONField subclass that supports the JSON schema validation.
     """
 
-    @cached_property
+    @property
     def _get_default(self):
         try:
             obj = [] if self.isArray else {}
@@ -62,16 +62,18 @@ class ValidatedJSONField(JSONField):
 
     def __init__(self, *args, schema=None, default=None, blank=False, **kwargs):
         self.schema = schema
+        self.jsschema = schema
         if schema is not None:
+            self.jsschema = to_json_schema(schema, {"supportPatternProperties": True})
             self.json_validator_cls = ExtendedJsonValidatorWithDefault(schema)
         else:
             self.json_validator_cls = None
 
         self.isArray = False
-        if(self.schema is not None):
-            if(default==list or default==[] or str(self.schema.get("type","")).lower()=="array"):
+        if(schema is not None):
+            if(default==list or default==[] or str(schema.get("type","")).lower()=="array"):
                 self.isArray=True
-            elif(default==dict or default=={} or str(self.schema.get("type","")).lower()=="object"):
+            elif(default==dict or default=={} or str(schema.get("type","")).lower()=="object"):
                 self.isArray=False
             elif(default is not None):
                 print("#WARNING# ValidatedJSONField: default argument is not allowed, as default is taken from schema", default)
