@@ -59,7 +59,7 @@ try:
 
         def map_serializer_field(self, auto_schema, direction):
             #print("schema", self.target.schema)
-            return self.target.schema
+            return self.target.schema or {"type":"object"}
 except: pass
 
     
